pub struct Matrix<T> {
pub data: Vec<T>,
/* private fields */
}Fields
data: Vec<T>Implementations
Sourceimpl<T> Matrix<T>
impl<T> Matrix<T>
Sourcepub fn new<U: AsPrimitive<usize>>(rows: U, cols: U, data: Vec<T>) -> Self
pub fn new<U: AsPrimitive<usize>>(rows: U, cols: U, data: Vec<T>) -> Self
Create a new matrix with the given number of rows and columns.
Sourcepub fn generate<F, U>(rows: U, cols: U, generator: F) -> Self
pub fn generate<F, U>(rows: U, cols: U, generator: F) -> Self
Create a new matrix using a function to generate the data.
Sourcepub fn get_ref(&self, row: usize, col: usize) -> Option<&T>
pub fn get_ref(&self, row: usize, col: usize) -> Option<&T>
Get a reference to the element at the given row and column.
Sourceimpl<T> Matrix<T>
impl<T> Matrix<T>
Sourcepub fn fill(rows: usize, cols: usize, datum: T) -> Self
pub fn fill(rows: usize, cols: usize, datum: T) -> Self
Create a new matrix with the given number of rows and columns filled with a given value.
Sourcepub fn get(&self, row: usize, col: usize) -> Option<T>
pub fn get(&self, row: usize, col: usize) -> Option<T>
Return the element at the given row and column.
Sourcepub fn insert_col(&self, n: usize, column: Vec<T>) -> Self
pub fn insert_col(&self, n: usize, column: Vec<T>) -> Self
Insert a column at position n.
Sourcepub fn insert_row(&self, n: usize, row: Vec<T>) -> Self
pub fn insert_row(&self, n: usize, row: Vec<T>) -> Self
Insert a row at position n.
pub fn transpose(&self) -> Self
Sourceimpl<T> Matrix<T>
impl<T> Matrix<T>
Sourcepub fn zeros<U: AsPrimitive<usize>>(rows: U, cols: U) -> Self
pub fn zeros<U: AsPrimitive<usize>>(rows: U, cols: U) -> Self
A matrix of all zeros.